@@ -953,18 +953,6 @@ void DataTest::testRow()
 		fail ("must fail");
 	}catch (NotFoundException&) {}
 
-	try
-	{
-		row4.set("field1", Var());
-		row4.addSortField(1);
-		row4.removeSortField(0);
-		fail ("must fail - field 1 is empty");
-	}
-	catch (IllegalStateException&)
-	{
-		row4.removeSortField(1);
-	}
-
 	row4.set("field0", 0);
 	row4.set("field1", 1);
 	row4.set("field2", 2);
@@ -1225,7 +1213,7 @@ void DataTest::testDateAndTime()
 	assert (dt.second() == t.second());
 	
 	Date d1(2007, 6, 15);
-	d1.assign(d.year() - 1, d.month(), d.day());
+	d1.assign(d.year() - 1, d.month(), (d.month() == 2 && d.day() == 29) ? 28 : d.day());
 	assert (d1 < d); assert (d1 != d);
 
 	d1.assign(d.year() - 1, 12, d.day());
@@ -1237,7 +1225,7 @@ void DataTest::testDateAndTime()
 		assert (d1 < d); assert (d1 != d);
 	}
 
-	d1.assign(d.year() + 1, d.month(), d.day());
+	d1.assign(d.year() + 1, d.month(), (d.month() == 2 && d.day() == 29) ? 28 : d.day());
 	assert (d1 > d); assert (d1 != d);
 	
 	d1.assign(d.year() + 1, 1, d.day());
